const { serializeError } = require('../../src/utils')

describe('utils module', () => {
  it('exports the serializeError function', () => {
    expect(serializeError).toBeDefined()
  })
  it('is a function', () => {
    expect(serializeError).toBeInstanceOf(Function)
  })

  it('throws an error on wrong argument type', () => {
    expect(() => serializeError(1)).toThrow(
      'Can only handle instances of "Error". Found instance of "number"'
    )
    expect(() => serializeError('one')).toThrow(
      'Can only handle instances of "Error". Found instance of "string"'
    )
    expect(() => serializeError([1, 'one'])).toThrow(
      'Can only handle instances of "Error". Found instance of "object"'
    )
    expect(() => serializeError({ one: 1 })).toThrow(
      'Can only handle instances of "Error". Found instance of "object"'
    )
  })

  it('serializes an error correctly', () => {
    const message = 'Just a test, relax...'
    const testError = new Error(message)
    const serializedError = serializeError(testError)
    expect(serializedError).toBeInstanceOf(Object)
    expect(serializedError).toHaveProperty('error')
    const { error } = serializedError
    expect(error).toEqual(expect.stringContaining('name'))
    expect(() => JSON.parse(error)).not.toThrow()
    const parsedError = JSON.parse(error)
    expect(parsedError).toMatchObject({
      name: 'Error',
      message,
      stack: testError.stack
    })
  })
})
