# Python Workers

A Python worker is expected to do the following:

1. Send a `{"data": "[NAME] ready"}` JSON object when ready to process commands.
2. Run a REPL (read-evaluate-print loop) that accepts and prints JSON formatted strings

The JSON object shall contain
  * `type` type of instruction
  * `command` (optional) 

Instruction types
  * `options` returns possible options for the interface
  * `ports` returns a list of available ports
  * `commands` returns a list of accepted commands
  * `execute` executes a command 

The execute type expects
  * `command` the command from the list of `commands` to run.
  * `args` a list of arguments

Execute shall implement at least the following commands
  * `read` to read data from the worker
  * `write` to write data to the worker
  * `ask` to write data and immediately read a response

The response JSON contains at least one of the following sections:
* `data` for the results
* `error` with information about what failed

## Options

The option object shall contain at least the following information:
* `name`: Name of the option
* `type`: Type (Int, Float, String)

It can also contain any of these additional informations:
* `description`: A short description of the option
* `values`: List of allowed values. If the list contains the empty element, any value of the type is allowed

## Ports

Ports shall contain at least the following information:
* `device`: information for the driver, how to connect to the device
* `name`: System name for the device

It can also contain any of the following informations:
* `description`: Short description
* `specific`: Interface specific information