import json
import ctypes
from utils import handle_exception

t32api = ctypes.cdll.LoadLibrary('t32api.dll')

class LauterbachWorker:

    connection = None

    @staticmethod
    def ports():
        try:

            a = t32api.T32_Config(b'NODE=', b'localhost')
            b = t32api.T32_Config(b'PACKLEN=', b'1042')
            c = t32api.T32_Config(b'PORT=', b'20000')
            d = t32api.T32_Init()
            e = t32api.T32_Attach(1)
            f = t32api.T32_Nop()
            g = t32api.T32_Exit()

            #print(a, b, c, d ,e ,f ,g)

            ports = []

            for port in driverPorts:
                obj = {
                    "address": port.address,
                    "bus": port.bus,
                    "manufacturer": port.manufacturer,
                    "product": port.product,
                    "serial_number": port.serial_number,
                    "idProduct": port.idProduct,
                    "idVendor": port.idVendor
                }
                ports.append(obj)

            return json.dumps({
                "data": ports
            })

        except Exception as error:
            return handle_exception(error)

    def timeout(self, value):
        try:
            self.connection.timeout = value
            return json.dumps({
                "data": {
                    "timeout": value
                }
            })

        except Exception as error:
            return handle_exception(error)

    def connect(self, idVendor, idProduct):
        try:
            self.connection = usbtmc.Instrument(idVendor, idProduct)
            return json.dumps({
                "data": {
                    "device": [idVendor, idProduct]
                }
            })
        except Exception as error:
            return handle_exception(error)
            
    def write(self, string):
        try:
            self.connection.write(string)
            return json.dumps({
                "data": {
                    "string": string
                }
            })
        except Exception as error:
            return handle_exception(error)

    def read(self):
        try:
            response = self.connection.read()

            return json.dumps({
                "data": {
                    "response": response
                }
            })
        except Exception as error:
            return handle_exception(error)

    def close(self):
        try:
            self.connection.close()
            return json.dumps({
                "data": {}
            })
        except Exception as error:
            return handle_exception(error)

    def __exit__(self, exc_type, exc_value, traceback):
        if self.connection is not None:
            self.connection.close()
            del self.connection
            self.connection = None

worker = LauterbachWorker()

with open("lauterbach.json", "w") as file:
    file.write(worker.ports()+',\n')