import sys
import time
import random
import json
from utils import handle_exception
 
 
class TestClass:
    def __init__(self, device):
        self.timeout = 2
        self.buffer = None
        self.connected = True

    def write(self, string):
        if not self.connected:
            raise Exception('Not connected!')
        self.buffer = string

    def read(self):
        if not self.connected:
            raise Exception('Not connected!')
        buffer = self.buffer
        self.buffer = None
        if buffer is None:
            time.sleep(self.timeout)
            raise Exception('Timeout!')
        if buffer == '*IDN?':
            return "TEST DEVICE, V2.3, S/N:31572394792"
        if buffer == 'SCALAR?':
            return "{:.4f} DCV".format(3.3*random.random())
        if buffer == 'ARRAY?':
            return "CURVE? {}".format(','.join([str(random.randint(0, 255)) for i in range(50)]))
        raise Exception('Command not found!')

    def ask(self, string):
        self.write(string)
        return self.read()

    def close(self):
        self.connected = False


class TestWorker:
    OPTIONS = [
        {"name": "port", "type": "String"},
        {"name": "baudrate", "type": "Int", "values": [
            50, 75, 110, 134, 150, 200, 300, 600, 1200, 1800, 2400, 4800, 9600, 19200, 38400, 57600, 115200]},
    ]

    connection = None

    @staticmethod
    def ports():
        driverPorts = [
            {'name': 'Port 22', 'device': '22'},
            {'name': 'Port 80', 'device': '80'},
        ]

        ports = []

        for port in driverPorts:
            obj = {
                "name": port['name'],
                "device": port['device'],
            }
            ports.append(obj)

        return ports

    def timeout(self, value):
        self.connection.timeout = value
        return {
            "timeout": value
        }

    def connect(self, device):
        self.connection = TestClass(device)
        return {
            "device": device
        }

    def write(self, string):
        self.connection.write(string)
        return {
            "string": string
        }

    def read(self):
        response = self.connection.read()
        return {
            "response": response
        }

    def ask(self, string):
        response = self.connection.ask(string)
        return {
            "response": response
        }

    def close(self):
        self.connection.close()
        return {}


worker = TestWorker()
print(json.dumps({"data": "Testworker ready"}), flush=True)

for line in sys.stdin:
    try:
        command = json.loads(line)
        if command['type'] == 'ports':
            data = TestWorker.ports()
        elif command['type'] == 'options':
            data = TestWorker.OPTIONS
        elif command['type'] == 'commands':
            data = [func for func in dir(TestWorker) if callable(getattr(TestWorker, func)) and not func.startswith('__')]
        elif command['type'] == 'connect':
            options = command['options'] if 'options' in command else {}
            data = worker.connect(command['device'], **options)
        elif command['type'] == 'read':
            data = worker.read()
        elif command['type'] == 'write':
            data = worker.write(command['data'])
        elif command['type'] == 'ask':
            data = worker.ask(command['data'])
        else:
            raise Exception('Command type "{}" is not supported.'.format(command['type']))
        print(json.dumps({"data": data}), flush=True)
    except Exception as error:
        print(handle_exception(error), flush=True)
