import json
import USBBlaster
from utils import handle_exception

 
class USBBlasterWorker:

    connection = None

    @staticmethod
    def ports():
        try:
            connection = USBBlaster.USBBlaster(IRbefore=4, IRafter=0, DRbefore=1, DRafter=0)
            driverPorts = connection.scanChain()
            del connection

            ports = []

            for index, port in enumerate(driverPorts):
                obj = {
                    "tap": index,
                    "ID": port,
                }
                ports.append(obj)

            return json.dumps({
                "data": ports
            })

        except Exception as error:
            return handle_exception(error)

    def connect(self):
        try:
            self.connection = USBBlaster.USBBlaster(IRbefore=4, IRafter=0, DRbefore=1, DRafter=0)
            return json.dumps({
                "data": {
                    "device": True
                }
            })
        except Exception as error:
            return handle_exception(error)
            
    def write(self, string):
        try:
            encodedString = string.encode('ascii')
            self.connection.write(encodedString)
            return json.dumps({
                "data": {
                    "string": string,
                    "encodedString": str(encodedString)
                }
            })
        except Exception as error:
            return handle_exception(error)

    def read(self):
        try:
            original_response = self.connection.readline()
            response = original_response.decode('ascii').strip()
            garbage = []
            while self.connection.in_waiting:
                garbage.append(str(self.connection.readline()))

            return json.dumps({
                "data": {
                    "response": response,
                    "originalResponse": str(original_response),
                    "garbage": garbage
                }
            })
        except Exception as error:
            return handle_exception(error)

    def close(self):
        try:
            self.connection = False
            return json.dumps({
                "data": {}
            })
        except Exception as error:
            return handle_exception(error)

worker = USBBlasterWorker()

print(USBBlasterWorker.ports())
with open("usb_blaster.json", "w") as file:
    file.write(worker.connect())
    file.write(worker.write("*IDN?\r\n")+',\n')
    file.write(worker.read()+',\n')
    file.write(worker.write("MEAS?\r\n")+',\n')
    file.write(worker.read()+',\n')
    file.write(worker.write("VAL?\r\n")+',\n')
    file.write(worker.read()+',\n')
    file.write(worker.close()+',\n')