import sys
import json
import usbtmc
from utils import handle_exception


class USBTMCWorker:
    OPTIONS = []

    connection = None

    @staticmethod
    def ports():
        driverPorts = usbtmc.list_devices()

        ports = []

        for port in driverPorts:
            obj = {
                "device": ':'.join([str(port.idVendor), str(port.idProduct)]),
                "name": port.product,
                "address": port.address,
                "bus": port.bus,
                "manufacturer": port.manufacturer,
                "product": port.product,
                "serial_number": port.serial_number,
                "idProduct": port.idProduct,
                "idVendor": port.idVendor
            }
            ports.append(obj)

        return ports

    def timeout(self, value):
        self.connection.timeout = value
        return {
            "timeout": value
        }

    def connect(self, device):
        [idVendor, idProduct] = device.split(':')
        self.connection = usbtmc.Instrument(int(idVendor), int(idProduct))
        return {
            "device": device
        }

    def write(self, string):
        self.connection.write(string)
        return {
            "string": string
        }

    def read(self):
        response = self.connection.read()
        return {
            "response": response
        }

    def ask(self, string):
        response = self.connection.ask(string)
        return {
            "response": response
        }

    def close(self):
        self.connection.close()
        return {}

    def __exit__(self, exc_type, exc_value, traceback):
        if self.connection is not None:
            self.connection.close()
            del self.connection
            self.connection = None


worker = USBTMCWorker()
print(json.dumps({"data": "USBTMC ready"}), flush=True)

for line in sys.stdin:
    try:
        command = json.loads(line)
        if command['type'] == 'ports':
            res = USBTMCWorker.ports()
        elif command['type'] == 'options':
            res = USBTMCWorker.OPTIONS
        elif command['type'] == 'connect':
            options = command['options'] if 'options' in command else {}
            res = worker.connect(command['device'], **options)
        elif command['type'] == 'read':
            res = worker.read()
        elif command['type'] == 'write':
            res = worker.write(command['data'])
        elif command['type'] == 'ask':
            res = worker.ask(command['data'])
        print(json.dumps({"data": res}), flush=True)
    except Exception as error:
        print(handle_exception(error), flush=True)
